@@ -33,7 +33,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("=", column, value))
+        if value:
+            self.conditions.append(("=", column, value))
         return self
 
     def eq_all(self, params: list):
@@ -42,7 +43,8 @@ class ConditionWrapper:
         :param params: 参数[("column","value")]
         :return:
         """
-        [self.eq(*item) for item in params]
+        if params:
+            [self.eq(*item) for item in params if item]
         return self
 
     def ne(self, column, value):
@@ -52,7 +54,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("<>", column, value))
+        if value:
+            self.conditions.append(("<>", column, value))
         return self
 
     def gt(self, column, value):
@@ -62,7 +65,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append((">", column, value))
+        if value:
+            self.conditions.append((">", column, value))
         return self
 
     def ge(self, column, value):
@@ -72,7 +76,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append((">=", column, value))
+        if value:
+            self.conditions.append((">=", column, value))
         return self
 
     def lt(self, column, value):
@@ -82,7 +87,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("<", column, value))
+        if value:
+            self.conditions.append(("<", column, value))
         return self
 
     def le(self, column, value):
@@ -92,7 +98,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("<=", column, value))
+        if value:
+            self.conditions.append(("<=", column, value))
         return self
 
     def between(self, column, value1, value2):
@@ -134,7 +141,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("LIKE", column, value))
+        if value:
+            self.conditions.append(("LIKE", column, value))
         return self
 
     def notLike(self, column, value):
@@ -144,7 +152,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("NOT_LIKE", column, value))
+        if value:
+            self.conditions.append(("NOT_LIKE", column, value))
         return self
 
     def like_left(self, column, value):
@@ -154,7 +163,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("LIKE_LEFT", column, value))
+        if value:
+            self.conditions.append(("LIKE_LEFT", column, value))
         return self
 
     def like_right(self, column, value):
@@ -164,7 +174,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("LIKE_RIGHT", column, value))
+        if value:
+            self.conditions.append(("LIKE_RIGHT", column, value))
         return self
 
     def is_null(self, column):
@@ -192,7 +203,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("IN", column, value))
+        if value:
+            self.conditions.append(("IN", column, value))
         return self
 
     def not_in(self, column, value):
@@ -202,7 +214,8 @@ class ConditionWrapper:
         :param value: 参考值
         :return:
         """
-        self.conditions.append(("NOT_IN", column, value))
+        if value:
+            self.conditions.append(("NOT_IN", column, value))
         return self
 
     def group(self, column):
