@@ -31,7 +31,7 @@ define("application_path", default=f"{os.path.dirname(sys.argv[0])}", type=str,
 define("cookie_secret", default="hRHQlJoUQIiNai2MLV9fQV3YDpxWrUHQp/jnfF9riQk=", type=str, help="cookie 秘钥 ")
 define("static_path", default=os.path.join(f"{os.path.dirname(sys.argv[0])}", "static"), type=str, help="静态资源目录")
 define("aes_key", default="haohaoxuexi", type=str, help="aes加密key")
-
+define("data_server", default="http://127.0.0.1:8901", type=str, help="数据服务")
 define("profile", default="profiles.config", type=str, help="配置文件")
 define("port", default="8080", type=int, help="服务监听端口")
 define("handler_path", default="handlers", type=str, help="处理器文件存储路径")
@@ -104,7 +104,8 @@ class WebServer:
         # 4、启动时创建数据库连接池
         tornado.ioloop.IOLoop.current().run_sync(InitConnectionPool.create_pool)
         # 5、自动化注册Handler处理类，
-        self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}", options.handler_path)
+        self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}",
+                                 options.handler_path)
         self.app = tornado.web.Application(
             RouterMapping.instance(),
             cookie_secret=options.cookie_secret,
